==> pgcalc2-2.2-4.tar.gz: pgcalc2-2.2-4/src/calctypes.cc <==
#include "calctypes.h"

const btnDesc BtnDesc[] = {
                    { "btn0", ba0, "Press to input '0'" },
                    { "btn1", ba1, "Press to input '1'" },
                    { "btn2", ba2, "Press to input '2'" },
                    { "btn3", ba3, "Press to input '3'" },
                    { "btn4", ba4, "Press to input '4'" },
                    { "btn5", ba5, "Press to input '5'" },
                    { "btn6", ba6, "Press to input '6'" },
                    { "btn7", ba7, "Press to input '7'" },
                    { "btn8", ba8, "Press to input '8'" },
                    { "btn9", ba9, "Press to input '9'" },
                    { "btnDot", baDot, "Press to input '.' sign" },
                    { "btnSeparator", baSeparator, "Press to input ',' sign" },
                    { "btnEnter", baEnter, "Press to accept inputed value" },
                    { "btnCancel", baCancel, "Press to cancel operation" },
                    { "btnBackSpace", baBackSpace, "Press to delete character\nbefore cursor." },
                    { "btnDel", baDel, "Press to delete character\nunder cursor" },
                    { "btnClear", baClear, "Press to clear input line and history" },
                    { "btnClose", baClose, "Press to close calculator" },

                    { "btnAdd", baAdd, "Algebraic: input '+' sign for addition\nRPN: make addition" },
                    { "btn+", baAdd, "Algebraic: input '+' sign for addition\nRPN: make addition" },

                    { "btnSub", baSub, "Algebraic: input '-' sign for subtraction\nRPN: make subtraction" },
                    { "btn-", baSub, "Algebraic: input '-' sign for subtraction\nRPN: make subtraction" },

                    { "btnMul", baMul, "Algebraic: input '*' sign for multiplication\nRPN: make multiplication" },
                    { "btn*", baMul, "Algebraic: input '*' sign for multiplication\nRPN: make multiplication" },

                    { "btnDiv", baDiv, "Algebraic: input '/' sign for division\nRPN: make division" },
                    { "btn/", baDiv, "Algebraic: input '/' sign for division\nRPN: make division" },

                    { "btnPercent", baPercent, "Algebraic: input '%' sign for calculate percents\nRPN: calculate percents" },
                    { "btn%", baPercent, "Algebraic: input '%' sign for calculate percents\nRPN: calculate percents" },
                    { "btnPercentT", baPercentT, "Algebraic: input '%' sign for calculate percents\nRPN: calculate percents" },
                    { "btnPercentCH", baPercentCH, "Algebraic: input '%' sign for calculate percents\nRPN: calculate percents" },

                    { "btnFactorial", baFactorial, "Algebraic: input '!' sign for factorial calculation\nRPN: calculate factorial" },
                    { "btn!", baFactorial, "Algebraic: input '!' sign for factorial calculation\nRPN: calculate factorial" },

                    { "btnSet", baSet, "Algebraic: input '=' sign for assign value\nto existing variable" },
                    { "btn=", baSet, "Algebraic: input '=' sign for assign value\nto existing variable" },

                    { "btnF1", baF1, "Function key no.1" },
                    { "btnF2", baF2, "Function key no.2" },
                    { "btnF3", baF3, "Function key no.3" },
                    { "btnF4", baF4, "Function key no.4" },
                    { "btnF5", baF5, "Function key no.5" },
                    { "btnF6", baF6, "Function key no.6" },

                    { "btnApps", baApps, "N/A" },
                    { "btnMode", baMode, "Press to change working mode\nand working options" },
                    { "btnTool", baTool, "N/A" },
                    { "btnVar", baVar, "Press to call menu\nwith defined variables" },
                    { "btnSto", baSto, "N/A" },
                    { "btnNxt", baNxt, "N/A" },
                    { "btnPlot", baPlot, "N/A" },

                    { "btnHist", baHist, "Press to activate history access mode" },
                    { "btnCmd", baCmd },
                    { "btnCat", baCat, "Press to call menu with all available\nfunctions/operators" },
                    { "btnEqw", baEqw, "N/A" },
                    { "btnSymb", baSymb, "N/A" },

                    { "btnEval", baEval, "" },
                    { "btnNum", baNum, "" },

                    { "btnNeg", baNeg, "Algebraic: input sign '-'\nRPN: press to change sign of value" },
                    { "btnX", baX, "Algebraic: press to call X variable" },
                    { "btn1perX", ba1perX, "Algebraic: press to input '1/'\nRPN: calculate inversion" },
                    { "btnYpowX", baYpowX, "Calculate value of Y raised to X" },
                    { "btnExp", baExp, "Calculate exponential" },
                    { "btnLn", baLn, "Calculate natural logarythm" },
                    { "btnSqrt", baSqrt, "Calculate value of square root" },
                    { "btnXpow2", baXpow2, "Calculate value of X\nraised to 2" },
                    { "btnXRoot", baXRoot, "Calculate value of X root\nbased on Y" },

                    { "btnSin", baSin, "Calculate sine of ..." },
                    { "btnASin", baASin, "Calculate angle whose\nsine value is equal ..." },
                    { "btnSinH", baSinH, "Calculate hyperbolic sine of ..." },
                    { "btnArgSH", baArgSH, "Calculate argsine of ..." },

                    { "btnCos", baCos, "Calculate cosine of ..." },
                    { "btnACos", baACos, "Calculate angle whose\ncosine value is equal ..." },
                    { "btnCosH", baCosH, "Calculate hyperbolic cosine of ..." },
                    { "btnArgCH", baArgCH, "Calculate argcosine of ..." },

                    { "btnTan", baTan, "Calculate tangent of ..." },
                    { "btnATan", baATan, "Calculate angle whose\ntangent value is equal ..." },
                    { "btnTahH", baTanH, "Calculate hyperbolic tangent of ..." },
                    { "btnArgTH", baArgTH, "Calculate argtangent of ..." },

                    { "btnDeriv", baDeriv, "Calculate derivative DERIV(func,var)" },
                    { "btnDervx", baDervx, "" },
                    { "btnInteg", baInteg, "Calculate symbolic integration INT(func,var)" },
                    { "btnIntvx", baIntvx, "" },
                    { "btnIntegN", baIntegN, "Calculate integration using\nSimpson method INTS(func,var,from,to)" },

                    { "btnCTan", baCtg, "Calculate cotangent of ..."  },
                    { "btnACTan", baACtg, "Calculate angle whose\ncotangent value is equal ..." },
                    { "btnCTanH", baCtgH, "Calculate hyperbolic cotangent of ..." },
                    { "btnArgCTH", baArgCTH, "Calculate argcotangent of ..." },

                    { "btnEex", baEex, "Input sign 'E' to indicate exponential\nformat of number" },
                    { "btnALog", baALog, "Calculate value of 10 raised to ... " },
                    { "btnLog", baLog, "Calculate decimal logarythm of ..." },

                    { "btnArg", baArg, "Calculate arg of ... " },
                    { "btnConj", baConj, "Calculate conjunction of ..." },
                    { "btnInv", baInv, "Calculate inversion of ..." },
                    { "btnNorm", baNorm, "Calculate norm of ..." },
                    { "btnAbs", baAbs, "Calculate absolute value of ..." },

                    { "btnRoLBrace", baRoLBrace, "Input left round bracket" },
                    { "btn(", baRoLBrace, "Input left round bracket"  },
                    { "btnRoRBrace", baRoRBrace, "Input right round bracket"  },
                    { "btn)", baRoRBrace, "Input right round bracket" },
                    { "btnSqLBrace", baSqLBrace, "Input left square bracket" },
                    { "btn[", baSqLBrace, "Input left square bracket" },
                    { "btnSqRBrace", baSqRBrace, "Input right square bracket" },
                    { "btn]", baSqRBrace, "Input right square bracket" },
                    { "btnRndBracket", baRndBracket, "Input round braces" },
                    { "btnRndBraces", baRndBracket, "Input round braces" },
                    { "btn()", baRndBracket, "Input round braces" },
                    { "btnSqrBracket", baSqrBracket, "Input square braces" },
                    { "btnSqrBraces", baSqrBracket, "Input square braces" },
                    { "btn[]", baSqrBracket, "Input square braces" },
                    { "btnKlamry", baKlamry, "Input curly braces\n(indicate complex number)" },
                    { "btn{}", baKlamry, "Input curly braces\n(indicate complex number)" },
                    { "btnAbsBracket", baAbsBracket, "Input '||' braces" },
                    { "btn||", baAbsBracket, "Input '||' braces" },
                    { "btnAbsBrace", baAbsBrace, "Input '|' bracket" },
                    { "btn|", baAbsBrace, "Input '|' bracket" },
                    { "btnQuotas", baQuotas, "Input quotation marks\n(indicate string)" },
                    { "btnExpression", baExpression, "Input expression marks" },

                    { "btnUnderscore", baUnderscore, "Put underscore character\ninto input line" },
                    { "btn_", baUnderscore, "Put underscore character\ninto input line" },

                    { "btnEq", baEq, "Algebraic: input '==' operator\nMake EQUAL operation" },
                    { "btnNEq", baNEq, "Algebraic: input '<>' operator\nMake NOT EQUAL operation"  },
                    { "btnLess", baLess, "Algebraic: input '<' operator\nMake LESS operation" },
                    { "btnLessEq", baLessEq, "Algebraic: input '<=' operator\nMake LESS OR EQUAL operation" },
                    { "btnGreat", baGreat, "Algebraic: input '>' operator\nMake GREAT operation" },
                    { "btnGreatEq", baGreatEq, "Algebraic: input '>=' operator\nMake GREAT OR EQUAL operation" },

                    { "btnSum", baSum, "Algebraic: call SUM() function\nMake SUM operation on values on stack" },
                    { "btnAvg", baAvg, "Algebraic: call AVG() function\nMake AVG operation on values on stack" },
                    { "btnMax", baMax, "Algebraic: call MAX() function\nMake MAX operation on values on stack" },
                    { "btnMin", baMin, "Algebraic: call MIN() function\nMake MIN operation on values on stack" },

                    { "btnSpace", baSpace, "Input blank space character" },
                    { "btnPi", baPi, "Input symbol or value of PI" },
                    //{ "btnE", baE },
                    { "btnComplexI", baComplexI, "Input value of (0+i)" },
                    { "btnRe", baRe, "Get real part of complex number" },
                    { "btnIm", baIm, "Get imagine part of complex number" },

                    { "btnMathMenu", baMathMenu, "" },
                    { "btnRealMenu", baRealMenu, "" },
                    { "btnComplexMenu", baComplexMenu, "" },
                    { "btnCalcMenu", baCalcMenu, "" },
                    { "btnAlgMenu", baAlgMenu, "" },
                    { "btnSolveMenu", baSolveMenu, "" },
                    
                    { "btnHash", baHash, "Input # sign to indicate binary,\noctal or hexadecimal format" },
                    { "btn2Hex", ba2Hex, "Convert number to hexadecimal format\n(ex. #hF56DA)" },
                    { "btn2Oct", ba2Oct, "Convert number to octal format\n(ex. #o4237)" },
                    { "btn2Bin", ba2Bin, "Convert number to binary format\n(ex. #b11010011)" },
                    { "btn2Dec", ba2Dec, "Convert number to decimal format\n(ex. 3.12345)" },
                    { "btnBaseMenu", baBaseMenu, "Open menu with base\nconversion functions" },

                    { "btnDeg2Rad", baDeg2Rad, "Convert given value of angle\nto radians" },
                    { "btnRad2Deg", baRad2Deg, "Convert given value of angle\nto degrees" },
                    { "btnDeg", baDeg },
                    { "btnRad", baRad },
                    { "btnDegRad", baDegRad },
                    { "btnHyperMenu", baHyperMenu },
                    { "btnTrigMenu", baTrigMenu },
                    
                    { "btnUnitsMenu", baUnitsMenu, "Call menu with available units\nof measure" },
                    { "btnConvert", baConvert, "Convert given value with unit to\nselected unit of measure" },

                    { "btnConstants", baConstants, "" },
                    { "btnFinance", baFinance, "TVM Solver" },

                    { "btnDefVar", baDefVar, "Declare user variable" },
                    { "btnDelVar", baDelVar, "Delete user-defined variable" },
                    { "btnDefAssign", baDefAssign, "Declare variable and assign value" },

                    { "btnEdit", baEdit, "Edit" },
                    { "btnCopy", baCopy, "Copy to clipboard" },
                    { "btnPaste", baPaste, "Paste from clipboard" },
                    { "btnUndo", baUndo },
                    { "btnEcho", baEcho, "Copy to input line" },
                    { "btnDrop", baDrop, "Drop selected value from stack" },
                    { "btnSwap", baSwap, "Swap selected value and value below" },
                    { "btn2Top", ba2Top, "Put selected value to\ntop of the stack" },

                    { "btnAns", baAns, "Alg. only: Use to call result\nof previous calculation\n(ex. ANS(2) )" },
                    { "btnMode1", baMode1, "Press to switch to Mode 1" },
                    { "btnMode2", baMode2, "Press to switch to Mode 2" },
                    { "btnAlpha", baAlpha, "Press to switch to Alpha Mode" },
                    { "btnUp", baUp, "Alg.: move cursor up in history mode\nRPN: move cursor up in stack" },
                    { "btnDown", baDown, "Alg.: move cursor down in history mode\nRPN: move cursor down in stack" },
                    { "btnLeft", baLeft, "Move cursor to left in input line" },
                    { "btnRight", baRight, "Move cursor to right in input line" },
                    { "btnHome", baHome },
                    { "btnEnd", baEnd },
                    { "btnMinimize", baMinimize, "Minimize calculator to icon\nin the system tray" },

                    { "btnUser", baUser },
                    { "btnEntry", baEntry },

                    { "?", baUnknown }
                    };

==> pgcalc2-2.2-10.tar.gz: pgcalc2-2.2-10/src/calctypes.cc <==
#include "calctypes.h"

const btnDesc BtnDesc[] = {
                    { "btn0", ba0, "Press to input '0'" },
                    { "btn1", ba1, "Press to input '1'" },
                    { "btn2", ba2, "Press to input '2'" },
                    { "btn3", ba3, "Press to input '3'" },
                    { "btn4", ba4, "Press to input '4'" },
                    { "btn5", ba5, "Press to input '5'" },
                    { "btn6", ba6, "Press to input '6'" },
                    { "btn7", ba7, "Press to input '7'" },
                    { "btn8", ba8, "Press to input '8'" },
                    { "btn9", ba9, "Press to input '9'" },
                    { "btnDot", baDot, "Press to input '.' sign" },
                    { "btnSeparator", baSeparator, "Press to input ',' sign" },
                    { "btnEnter", baEnter, "Press to accept inputed value" },
                    { "btnCancel", baCancel, "Press to cancel operation" },
                    { "btnBackSpace", baBackSpace, "Press to delete character\nbefore cursor." },
                    { "btnDel", baDel, "Press to delete character\nunder cursor" },
                    { "btnClear", baClear, "Press to clear input line and history" },
                    { "btnClose", baClose, "Press to close calculator" },

                    { "btnAdd", baAdd, "Algebraic: input '+' sign for addition\nRPN: make addition" },
                    { "btn+", baAdd, "Algebraic: input '+' sign for addition\nRPN: make addition" },

                    { "btnSub", baSub, "Algebraic: input '-' sign for subtraction\nRPN: make subtraction" },
                    { "btn-", baSub, "Algebraic: input '-' sign for subtraction\nRPN: make subtraction" },

                    { "btnMul", baMul, "Algebraic: input '*' sign for multiplication\nRPN: make multiplication" },
                    { "btn*", baMul, "Algebraic: input '*' sign for multiplication\nRPN: make multiplication" },

                    { "btnDiv", baDiv, "Algebraic: input '/' sign for division\nRPN: make division" },
                    { "btn/", baDiv, "Algebraic: input '/' sign for division\nRPN: make division" },

                    { "btnPercent", baPercent, "Algebraic: input '%' sign for calculate percents\nRPN: calculate percents" },
                    { "btn%", baPercent, "Algebraic: input '%' sign for calculate percents\nRPN: calculate percents" },
                    { "btnPercentT", baPercentT, "Algebraic: input '%' sign for calculate percents\nRPN: calculate percents" },
                    { "btnPercentCH", baPercentCH, "Algebraic: input '%' sign for calculate percents\nRPN: calculate percents" },

                    { "btnFactorial", baFactorial, "Algebraic: input '!' sign for factorial calculation\nRPN: calculate factorial" },
                    { "btn!", baFactorial, "Algebraic: input '!' sign for factorial calculation\nRPN: calculate factorial" },

                    { "btnSet", baSet, "Algebraic: input '=' sign for assign value\nto existing variable" },
                    { "btn=", baSet, "Algebraic: input '=' sign for assign value\nto existing variable" },

                    { "btnF1", baF1, "Function key no.1" },
                    { "btnF2", baF2, "Function key no.2" },
                    { "btnF3", baF3, "Function key no.3" },
                    { "btnF4", baF4, "Function key no.4" },
                    { "btnF5", baF5, "Function key no.5" },
                    { "btnF6", baF6, "Function key no.6" },

                    { "btnApps", baApps, "N/A" },
                    { "btnMode", baMode, "Press to change working mode\nand working options" },
                    { "btnTool", baTool, "N/A" },
                    { "btnVar", baVar, "Press to call menu\nwith defined variables" },
                    { "btnSto", baSto, "N/A" },
                    { "btnNxt", baNxt, "N/A" },
                    { "btnPlot", baPlot, "N/A" },

                    { "btnHist", baHist, "Press to activate history access mode" },
                    { "btnCmd", baCmd, "N/A" },
                    { "btnCat", baCat, "Press to call menu with all available\nfunctions/operators" },
                    { "btnEqw", baEqw, "N/A" },
                    { "btnSymb", baSymb, "N/A" },

                    { "btnEval", baEval, "" },
                    { "btnNum", baNum, "" },

                    { "btnNeg", baNeg, "Algebraic: input sign '-'\nRPN: press to change sign of value" },
                    { "btnX", baX, "Algebraic: press to call X variable" },
                    { "btn1perX", ba1perX, "Algebraic: press to input '1/'\nRPN: calculate inversion" },
                    { "btnYpowX", baYpowX, "Calculate value of Y raised to X" },
                    { "btnExp", baExp, "Calculate exponential" },
                    { "btnLn", baLn, "Calculate natural logarythm" },
                    { "btnSqrt", baSqrt, "Calculate value of square root" },
                    { "btnXpow2", baXpow2, "Calculate value of X\nraised to 2" },
                    { "btnXRoot", baXRoot, "Calculate value of X root\nbased on Y" },

                    { "btnSin", baSin, "Calculate sine of ..." },
                    { "btnASin", baASin, "Calculate angle whose\nsine value is equal ..." },
                    { "btnSinH", baSinH, "Calculate hyperbolic sine of ..." },
                    { "btnArgSH", baArgSH, "Calculate argsine of ..." },

                    { "btnCos", baCos, "Calculate cosine of ..." },
                    { "btnACos", baACos, "Calculate angle whose\ncosine value is equal ..." },
                    { "btnCosH", baCosH, "Calculate hyperbolic cosine of ..." },
                    { "btnArgCH", baArgCH, "Calculate argcosine of ..." },

                    { "btnTan", baTan, "Calculate tangent of ..." },
                    { "btnATan", baATan, "Calculate angle whose\ntangent value is equal ..." },
                    { "btnTahH", baTanH, "Calculate hyperbolic tangent of ..." },
                    { "btnArgTH", baArgTH, "Calculate argtangent of ..." },

                    { "btnDeriv", baDeriv, "Calculate derivative DERIV(func,var)" },
                    { "btnDervx", baDervx, "" },
                    { "btnInteg", baInteg, "Calculate symbolic integration INT(func,var)" },
                    { "btnIntvx", baIntvx, "" },
                    { "btnIntegN", baIntegN, "Calculate integration using\nSimpson method INTS(func,var,from,to)" },

                    { "btnCTan", baCtg, "Calculate cotangent of ..."  },
                    { "btnACTan", baACtg, "Calculate angle whose\ncotangent value is equal ..." },
                    { "btnCTanH", baCtgH, "Calculate hyperbolic cotangent of ..." },
                    { "btnArgCTH", baArgCTH, "Calculate argcotangent of ..." },

                    { "btnEex", baEex, "Input sign 'E' to indicate exponential\nformat of number" },
                    { "btnALog", baALog, "Calculate value of 10 raised to ... " },
                    { "btnLog", baLog, "Calculate decimal logarythm of ..." },

                    { "btnArg", baArg, "Calculate arg of ... " },
                    { "btnConj", baConj, "Calculate conjunction of ..." },
                    { "btnInv", baInv, "Calculate inversion of ..." },
                    { "btnNorm", baNorm, "Calculate norm of ..." },
                    { "btnAbs", baAbs, "Calculate absolute value of ..." },

                    { "btnRoLBrace", baRoLBrace, "Input left round bracket" },
                    { "btn(", baRoLBrace, "Input left round bracket"  },
                    { "btnRoRBrace", baRoRBrace, "Input right round bracket"  },
                    { "btn)", baRoRBrace, "Input right round bracket" },
                    { "btnSqLBrace", baSqLBrace, "Input left square bracket" },
                    { "btn[", baSqLBrace, "Input left square bracket" },
                    { "btnSqRBrace", baSqRBrace, "Input right square bracket" },
                    { "btn]", baSqRBrace, "Input right square bracket" },
                    { "btnRndBracket", baRndBracket, "Input round braces" },
                    { "btnRndBraces", baRndBracket, "Input round braces" },
                    { "btn()", baRndBracket, "Input round braces" },
                    { "btnSqrBracket", baSqrBracket, "Input square braces" },
                    { "btnSqrBraces", baSqrBracket, "Input square braces" },
                    { "btn[]", baSqrBracket, "Input square braces" },
                    { "btnKlamry", baKlamry, "Input curly braces\n(indicate complex number)" },
                    { "btn{}", baKlamry, "Input curly braces\n(indicate complex number)" },
                    { "btnAbsBracket", baAbsBracket, "Input '||' braces" },
                    { "btn||", baAbsBracket, "Input '||' braces" },
                    { "btnAbsBrace", baAbsBrace, "Input '|' bracket" },
                    { "btn|", baAbsBrace, "Input '|' bracket" },
                    { "btnQuotas", baQuotas, "Input quotation marks\n(indicate string)" },
                    { "btnExpression", baExpression, "Input expression marks" },

                    { "btnUnderscore", baUnderscore, "Put underscore character\ninto input line" },
                    { "btn_", baUnderscore, "Put underscore character\ninto input line" },

                    { "btnEq", baEq, "Algebraic: input '==' operator\nMake EQUAL operation" },
                    { "btnNEq", baNEq, "Algebraic: input '<>' operator\nMake NOT EQUAL operation"  },
                    { "btnLess", baLess, "Algebraic: input '<' operator\nMake LESS operation" },
                    { "btnLessEq", baLessEq, "Algebraic: input '<=' operator\nMake LESS OR EQUAL operation" },
                    { "btnGreat", baGreat, "Algebraic: input '>' operator\nMake GREAT operation" },
                    { "btnGreatEq", baGreatEq, "Algebraic: input '>=' operator\nMake GREAT OR EQUAL operation" },

                    { "btnSum", baSum, "Algebraic: call SUM() function\nMake SUM operation on values on stack" },
                    { "btnAvg", baAvg, "Algebraic: call AVG() function\nMake AVG operation on values on stack" },
                    { "btnMax", baMax, "Algebraic: call MAX() function\nMake MAX operation on values on stack" },
                    { "btnMin", baMin, "Algebraic: call MIN() function\nMake MIN operation on values on stack" },

                    { "btnSpace", baSpace, "Input blank space character" },
                    { "btnPi", baPi, "Input symbol or value of PI" },
                    //{ "btnE", baE },
                    { "btnComplexI", baComplexI, "Input value of (0+i)" },
                    { "btnRe", baRe, "Get real part of complex number" },
                    { "btnIm", baIm, "Get imagine part of complex number" },

                    { "btnMathMenu", baMathMenu, "" },
                    { "btnRealMenu", baRealMenu, "" },
                    { "btnComplexMenu", baComplexMenu, "" },
                    { "btnCalcMenu", baCalcMenu, "" },
                    { "btnAlgMenu", baAlgMenu, "" },
                    { "btnSolveMenu", baSolveMenu, "" },
                    
                    { "btnHash", baHash, "Input # sign to indicate binary,\noctal or hexadecimal format" },
                    { "btn2Hex", ba2Hex, "Convert number to hexadecimal format\n(ex. #hF56DA)" },
                    { "btn2Oct", ba2Oct, "Convert number to octal format\n(ex. #o4237)" },
                    { "btn2Bin", ba2Bin, "Convert number to binary format\n(ex. #b11010011)" },
                    { "btn2Dec", ba2Dec, "Convert number to decimal format\n(ex. 3.12345)" },
                    { "btnBaseMenu", baBaseMenu, "Open menu with base\nconversion functions" },

                    { "btnDeg2Rad", baDeg2Rad, "Convert given value of angle\nto radians" },
                    { "btnRad2Deg", baRad2Deg, "Convert given value of angle\nto degrees" },
                    { "btnDeg", baDeg, "" },
                    { "btnRad", baRad, "" },
                    { "btnDegRad", baDegRad, "" },
                    { "btnHyperMenu", baHyperMenu, "" },
                    { "btnTrigMenu", baTrigMenu, "" },
                    
                    { "btnUnitsMenu", baUnitsMenu, "Call menu with available units\nof measure" },
                    { "btnConvert", baConvert, "Convert given value with unit to\nselected unit of measure" },

                    { "btnConstants", baConstants, "" },
                    { "btnFinance", baFinance, "TVM Solver" },

                    { "btnDefVar", baDefVar, "Declare user variable" },
                    { "btnDelVar", baDelVar, "Delete user-defined variable" },
                    { "btnDefAssign", baDefAssign, "Declare variable and assign value" },

                    { "btnEdit", baEdit, "Edit" },
                    { "btnCopy", baCopy, "Copy to clipboard" },
                    { "btnPaste", baPaste, "Paste from clipboard" },
                    { "btnUndo", baUndo, "" },
                    { "btnEcho", baEcho, "Copy to input line" },
                    { "btnDrop", baDrop, "Drop selected value from stack" },
                    { "btnSwap", baSwap, "Swap selected value and value below" },
                    { "btn2Top", ba2Top, "Put selected value to\ntop of the stack" },

                    { "btnAns", baAns, "Alg. only: Use to call result\nof previous calculation\n(ex. ANS(2) )" },
                    { "btnMode1", baMode1, "Press to switch to Mode 1" },
                    { "btnMode2", baMode2, "Press to switch to Mode 2" },
                    { "btnAlpha", baAlpha, "Press to switch to Alpha Mode" },
                    { "btnUp", baUp, "Alg.: move cursor up in history mode\nRPN: move cursor up in stack" },
                    { "btnDown", baDown, "Alg.: move cursor down in history mode\nRPN: move cursor down in stack" },
                    { "btnLeft", baLeft, "Move cursor to left in input line" },
                    { "btnRight", baRight, "Move cursor to right in input line" },
                    { "btnHome", baHome, "Move cursor to the begining of the input line" },
                    { "btnEnd", baEnd, "Move cursor to the end of the input line" },
                    { "btnMinimize", baMinimize, "Minimize calculator to icon\nin the system tray" },

                    { "btnUser", baUser, "No hint available" },
                    { "btnEntry", baEntry, "No hint available" },

                    { "?", baUnknown, "" }
                    };
